@@ -12,11 +12,11 @@ use HTTP::Response;
 use HTTP::Tiny;
 use Params::ValidationCompiler qw(validation_for);
 use Test::BDD::Cucumber::Definitions qw(S);
-use Test::BDD::Cucumber::Definitions::TypeConstraints qw(:all);
+use Test::BDD::Cucumber::Definitions::HTTP::Types qw(:all);
 use Test::More;
 use Try::Tiny;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 our @EXPORT_OK = qw(
     request_send
@@ -47,10 +47,10 @@ my $validator_header_set = validation_for(
     params => [
 
         # http request header name
-        { type => ValueString },
+        { type => HttpHeader },
 
         # http request header value
-        { type => ValueString },
+        { type => HttpString }
     ]
 );
 
@@ -66,7 +66,7 @@ my $validator_content_set = validation_for(
     params => [
 
         # http request content
-        { type => ValueString },
+        { type => HttpString },
     ]
 );
 
@@ -82,10 +82,10 @@ my $validator_request_send = validation_for(
     params => [
 
         # http request method
-        { type => ValueString },
+        { type => HttpMethod },
 
         # http request url
-        { type => ValueUrl },
+        { type => HttpUrl },
     ]
 );
 
@@ -126,7 +126,7 @@ my $validator_code_eq = validation_for(
     params => [
 
         # http response code
-        { type => ValueInteger },
+        { type => HttpCode },
     ]
 );
 
@@ -144,10 +144,10 @@ my $validator_header_eq = validation_for(
     params => [
 
         # http response header name
-        { type => ValueString },
+        { type => HttpHeader },
 
         # http response header value
-        { type => ValueString },
+        { type => HttpString },
 
     ]
 );
@@ -166,10 +166,10 @@ my $validator_header_re = validation_for(
     params => [
 
         # http response header name
-        { type => ValueString },
+        { type => HttpHeader },
 
         # http response header value
-        { type => ValueRegexp }
+        { type => HttpRegexp }
     ]
 );
 
@@ -188,7 +188,7 @@ my $validator_content_eq = validation_for(
     params => [
 
         # http response content
-        { type => ValueString },
+        { type => HttpString },
 
     ]
 );
@@ -207,7 +207,7 @@ my $validator_content_re = validation_for(
     params => [
 
         # http response content
-        { type => ValueRegexp }
+        { type => HttpRegexp }
     ]
 );
 
